@@ -158,27 +158,15 @@ class SignAndCreate(base.CreateCommand):
         attestor_ref=attestor_ref,
         api_version=api_version)
 
-    ca_api_version = ca_apis.GetApiVersion(self.ReleaseTrack())
-    # TODO(b/138859339): Remove when remainder of surface migrated to V1 API.
-    if ca_api_version == ca_apis.V1:
-      return containeranalysis.Client(
-          ca_api_version).CreateAttestationOccurrence(
-              project_ref=project_ref,
-              note_ref=note_ref,
-              artifact_url=normalized_artifact_url,
-              public_key_id=key_id,
-              signature=sign_response.signature,
-              plaintext=payload,
-              validation_callback=(validation_callback
-                                   if validation_enabled else None),
-          )
-    else:
-      return containeranalysis.Client(
-          ca_api_version).CreateGenericAttestationOccurrence(
-              project_ref=project_ref,
-              note_ref=note_ref,
-              artifact_url=normalized_artifact_url,
-              public_key_id=key_id,
-              signature=sign_response.signature,
-              plaintext=payload,
-          )
+    client = containeranalysis.Client(
+        ca_apis.GetApiVersion(self.ReleaseTrack()))
+    return client.CreateAttestationOccurrence(
+        project_ref=project_ref,
+        note_ref=note_ref,
+        artifact_url=normalized_artifact_url,
+        public_key_id=key_id,
+        signature=sign_response.signature,
+        plaintext=payload,
+        validation_callback=(validation_callback
+                             if validation_enabled else None),
+    )
